<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:alt="http://www.w3.org/1999/XSL/Transform-alternate"
xmlns:pr_sd="http://www.eo.ee/dev/xml/schemas/xmlschemadescriptors">

  <xsl:namespace-alias stylesheet-prefix="alt" result-prefix="xsl"/>
  <xsl:output method="xml" omit-xml-declaration="no" indent="yes" encoding="utf-8" />

  <xsl:variable name="edfont">font-family:"Arial Unicode MS";</xsl:variable>


  <xsl:template name="genItem">
    <xsl:variable name="ylakoma">'</xsl:variable>
    <xsl:choose>
      <xsl:when test="starts-with(text, $ylakoma)">
        <xsl:variable name="textStr">
          <xsl:choose>
            <xsl:when test="substring(text, 2, string-length(text) - 2) = ' '">
              <xsl:text>&#xA0;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="substring(text, 2, string-length(text) - 2)"></xsl:value-of>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <alt:text>
          <xsl:value-of select="$textStr"></xsl:value-of>
        </alt:text>
      </xsl:when>
      <xsl:when test="starts-with(text, '&lt;')">
        <xsl:text>&#x0d;&#x0a;</xsl:text>
        <xsl:value-of select="text" disable-output-escaping="yes"></xsl:value-of>
        <xsl:text>&#x0d;&#x0a;</xsl:text>
      </xsl:when>
      <xsl:when test="text = '='">
        <xsl:for-each select="../../../*[namespace-uri() != '']">
          <xsl:if test="element/show[. = 1]">
            <alt:apply-templates select="{name()}">
              <alt:with-param name="rada">
                <alt:value-of select="concat($rada, '{name(..)}[', $posnr_{local-name(..)}, ']/')"></alt:value-of>
              </alt:with-param>
            </alt:apply-templates>
          </xsl:if>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:variable name="idlopp">
          <xsl:choose>
            <xsl:when test="starts-with(text, '@')">
              <xsl:value-of select="concat('/', text)"></xsl:value-of>
            </xsl:when>
            <xsl:otherwise>/text()[1]</xsl:otherwise>
          </xsl:choose>
        </xsl:variable>
        <alt:element name="span">
          <alt:attribute name="id">
            <alt:value-of select="concat($rada, '{name(../../..)}[', $posnr_{local-name(../../..)}, ']{$idlopp}')"></alt:value-of>
          </alt:attribute>
          <alt:attribute name="lang">
            <alt:value-of select="$spell_lang"></alt:value-of>
          </alt:attribute>
          <alt:attribute name="title">
            <alt:value-of select="concat($rada, '{name(../../..)}[', $posnr_{local-name(../../..)}, ']{$idlopp}')"></alt:value-of>
          </alt:attribute>
          <xsl:if test="style != '-'">
            <alt:attribute name="style">
              <xsl:value-of select="style"></xsl:value-of>
            </alt:attribute>
          </xsl:if>
          <alt:attribute name="tabIndex">0</alt:attribute>
          <alt:value-of select="{text}"></alt:value-of>
        </alt:element>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  <!-- genItem -->

  
  <xsl:template match="/">
    <alt:stylesheet version="1.0" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
      <alt:output method="html" omit-xml-declaration="yes" indent="no" encoding="utf-8" />

      <alt:variable name="ul_style">margin-left:6mm;</alt:variable>
      <alt:variable name="no_output">sandybrown</alt:variable>

      <alt:template match="/">
        <html>
          <head>
            <title></title>
          </head>
          <alt:apply-templates select="*"></alt:apply-templates>
        </html>
      </alt:template>
      <!-- / -->

      
      <alt:template match="p:sr">
        <body lang="et">
          <alt:apply-templates select="*" />
        </body>
      </alt:template>
      <!-- sr -->

      
      <alt:template name="get_lang">
        <alt:choose>
          <alt:when test="lang('de')">de</alt:when>
          <alt:when test="lang('en')">en</alt:when>
          <alt:when test="lang('et')">et</alt:when>
          <alt:when test="lang('fi')">fi</alt:when>
          <alt:when test="lang('fr')">fr</alt:when>
          <alt:when test="lang('la')">la</alt:when>
          <alt:when test="lang('lt')">lt</alt:when>
          <alt:when test="lang('lv')">lv</alt:when>
          <alt:when test="lang('ru')">ru</alt:when>
          <alt:otherwise></alt:otherwise>
        </alt:choose>
      </alt:template>
      <!-- get_lang -->

      
      <xsl:apply-templates select="*/*"></xsl:apply-templates>

      
    </alt:stylesheet>
  </xsl:template>


  <!-- TEGELIK STYLESHEET ALGUS -->
  <xsl:template match="*">

    <xsl:if test="element/show[. = 1]">

      <alt:template match="{name()}">

        <alt:param name="rada"></alt:param>
        <alt:variable name="posnr_{local-name()}">
          <alt:number level="single" format="1"></alt:number>
        </alt:variable>
        <xsl:if test="element/content/item/text[. = '.']">
          <alt:variable name="spell_lang">
            <alt:call-template name="get_lang"></alt:call-template>
          </alt:variable>
        </xsl:if>

        <xsl:if test="element/space[. = 1]">
          <alt:variable name="posnr_elem">
            <alt:number level="single" count="*"  format="1"></alt:number>
          </alt:variable>
          <alt:if test="$posnr_elem > 1">
            <alt:text>&#xA0;</alt:text>
          </alt:if>
        </xsl:if>

        <xsl:for-each select="element/content/item">
          <xsl:choose>
            <xsl:when test="if != '-'">
              <alt:if test="{if}">
                <xsl:call-template name="genItem"></xsl:call-template>
              </alt:if>
            </xsl:when>
            <xsl:otherwise>
              <xsl:call-template name="genItem"></xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>

        <xsl:for-each select="element/after/item">
          <xsl:choose>
            <xsl:when test="if != '-'">
              <alt:if test="{if}">
                <xsl:call-template name="genItem"></xsl:call-template>
              </alt:if>
            </xsl:when>
            <xsl:otherwise>
              <xsl:call-template name="genItem"></xsl:call-template>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:for-each>

      </alt:template>

      <xsl:for-each select="*[namespace-uri() != '']">
        <xsl:variable name="qname">
          <xsl:value-of select="name()"></xsl:value-of>
        </xsl:variable>
        <xsl:if test="not(preceding::*[name() = $qname] or ancestor::*[name() = $qname])">
          <xsl:apply-templates select="." />
        </xsl:if>
      </xsl:for-each>

    </xsl:if>

  </xsl:template>
  
</xsl:stylesheet>
